@@ -4,7 +4,5 @@ var searchData=
   ['the_20appearance_20or_20capabilities_20of_20the_20device_1',['Modifying the appearance or capabilities of the device',['../group__kernel.html',1,'']]],
   ['the_20device_2',['the device',['../group__kernel.html',1,'Modifying the appearance or capabilities of the device'],['../syn_dropped.html#autotoc_md11',1,'Synchronizing the state of the device']]],
   ['the_20state_20of_20the_20device_3',['Synchronizing the state of the device',['../syn_dropped.html#autotoc_md11',1,'']]],
-  ['touch_20related_20functions_4',['Multi-touch related functions',['../group__mt.html',1,'']]],
-  ['tt_20events_5',['Receiving &lt;tt&gt;SYN_DROPPED&lt;/tt&gt; events',['../syn_dropped.html#autotoc_md10',1,'']]],
-  ['tt_20syn_5fdropped_20tt_20events_6',['Receiving &lt;tt&gt;SYN_DROPPED&lt;/tt&gt; events',['../syn_dropped.html#autotoc_md10',1,'']]]
+  ['touch_20related_20functions_4',['Multi-touch related functions',['../group__mt.html',1,'']]]
 ];
