@@ -3,7 +3,7 @@ var searchData=
   ['evdev_20ioctls_0',['evdev ioctls',['../ioctls.html',1,'']]],
   ['event_20and_20input_20property_20names_1',['Event and input property names',['../backwardscompatibility.html#autotoc_md15',1,'']]],
   ['event_20handling_2',['Event handling',['../group__events.html',1,'']]],
-  ['events_3',['Receiving &lt;tt&gt;SYN_DROPPED&lt;/tt&gt; events',['../syn_dropped.html#autotoc_md10',1,'']]],
+  ['events_3',['Receiving &lt;span class=&quot;tt&quot;&gt;SYN_DROPPED&lt;/span&gt; events',['../syn_dropped.html#autotoc_md10',1,'']]],
   ['events_20and_20syn_5fdropped_4',['Handling events and SYN_DROPPED',['../index.html#autotoc_md1',1,'']]],
   ['events_20before_20synchronizing_5',['Discarding events before synchronizing',['../syn_dropped.html#autotoc_md13',1,'']]],
   ['example_6',['Example',['../index.html#autotoc_md5',1,'']]]
