@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['receiving_20tt_20syn_5fdropped_20tt_20events_0',['Receiving &lt;tt&gt;SYN_DROPPED&lt;/tt&gt; events',['../syn_dropped.html#autotoc_md10',1,'']]],
+  ['receiving_20syn_5fdropped_20events_0',['Receiving &lt;span class=&quot;tt&quot;&gt;SYN_DROPPED&lt;/span&gt; events',['../syn_dropped.html#autotoc_md10',1,'']]],
   ['related_20functions_1',['Multi-touch related functions',['../group__mt.html',1,'']]],
   ['reporting_20bugs_2',['Reporting bugs',['../index.html#autotoc_md9',1,'']]],
   ['requirements_3',['Minimum requirements',['../backwardscompatibility.html#autotoc_md14',1,'']]]
