@@ -8,7 +8,7 @@ var indexSectionsWithContent =
   5: "l",
   6: "l",
   7: "acdefhilmoqrstu",
-  8: "abcdehiklstv"
+  8: "abcdehiklmnoprstvw"
 };
 
 var indexSectionNames =
